[zorg] r282623 - run python tests against i386 and x86_64 inferiors

Tim Hammerquist via llvm-commits llvm-commits at lists.llvm.org
Wed Sep 28 12:54:01 PDT 2016


Author: penryu
Date: Wed Sep 28 14:54:01 2016
New Revision: 282623

URL: http://llvm.org/viewvc/llvm-project?rev=282623&view=rev
Log:
run python tests against i386 and x86_64 inferiors

r281639 modified the python test suite to use the value of
LLDB_PYTHON_TESTSUITE_ARCH to determine the arch of the inferior
processes tested.

To ensure that lldb can debug both x86_64 and i386 inferiors, the zorg
lldb build should test against both of these architectures.

https://reviews.llvm.org/D24992

Modified:
    zorg/trunk/zorg/jenkins/build.py

Modified: zorg/trunk/zorg/jenkins/build.py
URL: http://llvm.org/viewvc/llvm-project/zorg/trunk/zorg/jenkins/build.py?rev=282623&r1=282622&r2=282623&view=diff
==============================================================================
--- zorg/trunk/zorg/jenkins/build.py (original)
+++ zorg/trunk/zorg/jenkins/build.py Wed Sep 28 14:54:01 2016
@@ -444,7 +444,7 @@ def lldb_builder():
     run_cmd("lldb", xcodebuild_cmd)
     footer()
 
     # Run LLDB Python test suite
 
     xcodebuild_cmd = [
         "xcodebuild",
@@ -452,9 +452,27 @@ def lldb_builder():
         "-configuration", build_configuration,
         "-scheme", "lldb-python-test-suite",
         "-derivedDataPath", conf.lldbbuilddir(),
+        "LLDB_PYTHON_TESTSUITE_ARCH=x86_64",
         "DEBUGSERVER_USE_FROM_SYSTEM=1"]
 
-    header("Build Xcode lldb-python-test-suite target")
+    header("Build Xcode lldb-python-test-suite (64-bit) target")
+    # For the unit tests, we don't want to stop the build if there are
+    # build errors.  We allow the JUnit/xUnit parser to pick this up.
+    run_cmd_errors_okay("lldb", xcodebuild_cmd)
+    footer()
+
+    # Run LLDB Python test suite (i386 inferiors)
+
+    xcodebuild_cmd = [
+        "xcodebuild",
+        "-arch", "x86_64",
+        "-configuration", build_configuration,
+        "-scheme", "lldb-python-test-suite",
+        "-derivedDataPath", conf.lldbbuilddir(),
+        "LLDB_PYTHON_TESTSUITE_ARCH=i386",
+        "DEBUGSERVER_USE_FROM_SYSTEM=1"]
+
+    header("Build Xcode lldb-python-test-suite (32-bit) target")
     # For the unit tests, we don't want to stop the build if there are
     # build errors.  We allow the JUnit/xUnit parser to pick this up.
     run_cmd_errors_okay("lldb", xcodebuild_cmd)
@@ -444,7 +444,7 @@ def lldb_builder():
     footer()
 
-    # Run LLDB Python test suite
+    # Run LLDB Python test suite (x86_64 inferiors)
 
     xcodebuild_cmd = [




More information about the llvm-commits mailing list